import functools
import haml

from bottle import template, DEBUG, BaseTemplate


class HamlTemplate(BaseTemplate):

    extensions = ['haml']

    def prepare(self, **options):
        from mako.template import Template
        from mako.lookup import TemplateLookup

        options.update({'input_encoding': self.encoding})
        options.setdefault('format_exceptions', bool(DEBUG))
        lookup = TemplateLookup(directories=self.lookup, **options)
        options['preprocessor'] = haml.preprocessor
        
        if self.source:
            self.tpl = Template(self.source, lookup=lookup, **options)
        else:
            self.tpl = Template(uri=self.name, filename=self.filename, lookup=lookup, **options)

    def render(self, *args, **kwargs):
        for dictarg in args:
            kwargs.update(dictarg)
        _defaults = self.defaults.copy()
        _defaults.update(kwargs)
        return self.tpl.render(**_defaults)

haml_template = functools.partial(template, template_adapter=HamlTemplate)



from setuptools import setup

dependencies = [
    'bottle',
    'pyhaml'
]

setup(
    name="bottle-haml",
    packages=["bottlehaml",],
    install_requires=dependencies,
    version="0.1",
    author="Zachary Jones",
    author_email="me@zacharytamas.com",
    license="BSD",
    url="https://github.com/wireload/bottle-haml",
    long_description=open('README.md').read(),
)